# Enkrypt Secure MCP Gateway

A secure gateway for Model Control Protocol (MCP) that enables safe and controlled access to MCP servers.

```bash
pip install secure-mcp-gateway
```

For documentation and usage instructions, [please visit our GitHub repository: https://github.com/enkryptai/secure-mcp-gateway](https://github.com/enkryptai/secure-mcp-gateway)
